EXPORTS
	??0CCDRecordBase@CommsDat@@QAE@K@Z @ 1 NONAME ; CommsDat::CCDRecordBase::CCDRecordBase(unsigned long)
	??0CMDBBinFieldBase@CommsDat@@QAE@K@Z @ 2 NONAME ; CommsDat::CMDBBinFieldBase::CMDBBinFieldBase(unsigned long)
	??0CMDBBinFieldBase@CommsDat@@QAE@XZ @ 3 NONAME ; CommsDat::CMDBBinFieldBase::CMDBBinFieldBase(void)
	??0CMDBElement@CommsDat@@QAE@K@Z @ 4 NONAME ; CommsDat::CMDBElement::CMDBElement(unsigned long)
	??0CMDBElement@CommsDat@@QAE@XZ @ 5 NONAME ; CommsDat::CMDBElement::CMDBElement(void)
	??0CMDBNumFieldBase@CommsDat@@QAE@K@Z @ 6 NONAME ; CommsDat::CMDBNumFieldBase::CMDBNumFieldBase(unsigned long)
	??0CMDBNumFieldBase@CommsDat@@QAE@XZ @ 7 NONAME ; CommsDat::CMDBNumFieldBase::CMDBNumFieldBase(void)
	??0CMDBRecordLinkBase@CommsDat@@QAE@K@Z @ 8 NONAME ; CommsDat::CMDBRecordLinkBase::CMDBRecordLinkBase(unsigned long)
	??0CMDBRecordLinkBase@CommsDat@@QAE@KPAVCMDBElement@1@@Z @ 9 NONAME ; CommsDat::CMDBRecordLinkBase::CMDBRecordLinkBase(unsigned long, class CommsDat::CMDBElement *)
	??0CMDBRecordLinkBase@CommsDat@@QAE@XZ @ 10 NONAME ; CommsDat::CMDBRecordLinkBase::CMDBRecordLinkBase(void)
	??0CMDBRecordSetBase@CommsDat@@QAE@K@Z @ 11 NONAME ; CommsDat::CMDBRecordSetBase::CMDBRecordSetBase(unsigned long)
	??0CMDBRecordSetBase@CommsDat@@QAE@XZ @ 12 NONAME ; CommsDat::CMDBRecordSetBase::CMDBRecordSetBase(void)
	??0CMDBSession@CommsDat@@AAE@XZ @ 13 NONAME ; CommsDat::CMDBSession::CMDBSession(void)
	??0CMDBTextFieldBase@CommsDat@@QAE@K@Z @ 14 NONAME ; CommsDat::CMDBTextFieldBase::CMDBTextFieldBase(unsigned long)
	??0CMDBTextFieldBase@CommsDat@@QAE@XZ @ 15 NONAME ; CommsDat::CMDBTextFieldBase::CMDBTextFieldBase(void)
	??0MMetaDatabase@CommsDat@@IAE@XZ @ 16 NONAME ; CommsDat::MMetaDatabase::MMetaDatabase(void)
	??1CCommsDatUtils@CommsDatUtils@@UAE@XZ @ 17 NONAME ; CommsDatUtils::CCommsDatUtils::~CCommsDatUtils(void)
	??1CMDBBinFieldBase@CommsDat@@UAE@XZ @ 18 NONAME ; CommsDat::CMDBBinFieldBase::~CMDBBinFieldBase(void)
	??1CMDBElement@CommsDat@@UAE@XZ @ 19 NONAME ; CommsDat::CMDBElement::~CMDBElement(void)
	??1CMDBGenericRecord@CommsDat@@UAE@XZ @ 20 NONAME ; CommsDat::CMDBGenericRecord::~CMDBGenericRecord(void)
	??1CMDBRecordLinkBase@CommsDat@@UAE@XZ @ 21 NONAME ; CommsDat::CMDBRecordLinkBase::~CMDBRecordLinkBase(void)
	??1CMDBRecordSetBase@CommsDat@@UAE@XZ @ 22 NONAME ; CommsDat::CMDBRecordSetBase::~CMDBRecordSetBase(void)
	??1CMDBSession@CommsDat@@UAE@XZ @ 23 NONAME ; CommsDat::CMDBSession::~CMDBSession(void)
	??1CMDBTextFieldBase@CommsDat@@UAE@XZ @ 24 NONAME ; CommsDat::CMDBTextFieldBase::~CMDBTextFieldBase(void)
	??1MMetaDatabase@CommsDat@@UAE@XZ @ 25 NONAME ; CommsDat::MMetaDatabase::~MMetaDatabase(void)
	??4CMDBBinFieldBase@CommsDat@@QAEAAV01@ABVTDesC8@@@Z @ 26 NONAME ; class CommsDat::CMDBBinFieldBase & CommsDat::CMDBBinFieldBase::operator=(class TDesC8 const &)
	??4CMDBNumFieldBase@CommsDat@@QAEAAV01@H@Z @ 27 NONAME ; class CommsDat::CMDBNumFieldBase & CommsDat::CMDBNumFieldBase::operator=(int)
	??4CMDBRecordLinkBase@CommsDat@@QAEAAV01@K@Z @ 28 NONAME ; class CommsDat::CMDBRecordLinkBase & CommsDat::CMDBRecordLinkBase::operator=(unsigned long)
	??4CMDBTextFieldBase@CommsDat@@QAEAAV01@ABVTDesC16@@@Z @ 29 NONAME ; class CommsDat::CMDBTextFieldBase & CommsDat::CMDBTextFieldBase::operator=(class TDesC16 const &)
	??BCMDBRecordLinkBase@CommsDat@@QAEKXZ @ 30 NONAME ; CommsDat::CMDBRecordLinkBase::operator unsigned long(void)
	?Attributes@CMDBElement@CommsDat@@QBEKXZ @ 31 NONAME ; unsigned long CommsDat::CMDBElement::Attributes(void) const
	?CancelAllNotifications@CMDBSession@CommsDat@@QAEHXZ @ 32 NONAME ; int CommsDat::CMDBSession::CancelAllNotifications(void)
	?CancelNotification@MMetaDatabase@CommsDat@@QAEHAAVCMDBSession@2@AAVTRequestStatus@@@Z @ 33 NONAME ; int CommsDat::MMetaDatabase::CancelNotification(class CommsDat::CMDBSession &, class TRequestStatus &)
	?CheckReadCapability@CCommsDatUtils@CommsDatUtils@@QAEHABVTDesC16@@PBVRMessagePtr2@@@Z @ 34 NONAME ; int CommsDatUtils::CCommsDatUtils::CheckReadCapability(class TDesC16 const &, class RMessagePtr2 const *)
	?CheckWriteCapability@CCommsDatUtils@CommsDatUtils@@QAEHABVTDesC16@@PBVRMessagePtr2@@@Z @ 35 NONAME ; int CommsDatUtils::CCommsDatUtils::CheckWriteCapability(class TDesC16 const &, class RMessagePtr2 const *)
	?ClearAttributes@CMDBElement@CommsDat@@QAEXK@Z @ 36 NONAME ; void CommsDat::CMDBElement::ClearAttributes(unsigned long)
	?Close@CMDBSession@CommsDat@@QAEXXZ @ 37 NONAME ; void CommsDat::CMDBSession::Close(void)
	?CommitTransactionL@CMDBSession@CommsDat@@QAEXXZ @ 38 NONAME ; void CommsDat::CMDBSession::CommitTransactionL(void)
	?ConstructL@CMDBSession@CommsDat@@AAEHVTVersion@@@Z @ 39 NONAME ; int CommsDat::CMDBSession::ConstructL(class TVersion)
	?CreateCopyRecordL@CCDRecordBase@CommsDat@@SAPAVCMDBRecordBase@2@AAV32@@Z @ 40 NONAME ; class CommsDat::CMDBRecordBase * CommsDat::CCDRecordBase::CreateCopyRecordL(class CommsDat::CMDBRecordBase &)
	?DeleteL@MMetaDatabase@CommsDat@@QAEXAAVCMDBSession@2@@Z @ 41 NONAME ; void CommsDat::MMetaDatabase::DeleteL(class CommsDat::CMDBSession &)
	?ElementId@CMDBElement@CommsDat@@QBEKXZ @ 42 NONAME ; unsigned long CommsDat::CMDBElement::ElementId(void) const
	?FindL@MMetaDatabase@CommsDat@@QAEHAAVCMDBSession@2@@Z @ 43 NONAME ; int CommsDat::MMetaDatabase::FindL(class CommsDat::CMDBSession &)
	?GetAttribPtr@CCDRecordBase@CommsDat@@MBEPAEH@Z @ 44 NONAME ; unsigned char * CommsDat::CCDRecordBase::GetAttribPtr(int) const
	?GetAttribPtr@CMDBBinFieldBase@CommsDat@@UBEPAEH@Z @ 45 NONAME ; unsigned char * CommsDat::CMDBBinFieldBase::GetAttribPtr(int) const
	?GetAttribPtr@CMDBElement@CommsDat@@UBEPAEH@Z @ 46 NONAME ; unsigned char * CommsDat::CMDBElement::GetAttribPtr(int) const
	?GetAttribPtr@CMDBGenericRecord@CommsDat@@UBEPAEH@Z @ 47 NONAME ; unsigned char * CommsDat::CMDBGenericRecord::GetAttribPtr(int) const
	?GetAttribPtr@CMDBNumFieldBase@CommsDat@@UBEPAEH@Z @ 48 NONAME ; unsigned char * CommsDat::CMDBNumFieldBase::GetAttribPtr(int) const
	?GetAttribPtr@CMDBRecordLinkBase@CommsDat@@MBEPAEH@Z @ 49 NONAME ; unsigned char * CommsDat::CMDBRecordLinkBase::GetAttribPtr(int) const
	?GetAttribPtr@CMDBRecordSetBase@CommsDat@@MBEPAEH@Z @ 50 NONAME ; unsigned char * CommsDat::CMDBRecordSetBase::GetAttribPtr(int) const
	?GetAttribPtr@CMDBTextFieldBase@CommsDat@@UBEPAEH@Z @ 51 NONAME ; unsigned char * CommsDat::CMDBTextFieldBase::GetAttribPtr(int) const
	?GetFieldByIdL@CMDBGenericRecord@CommsDat@@UAEPAVCMDBElement@2@K@Z @ 52 NONAME ; class CommsDat::CMDBElement * CommsDat::CMDBGenericRecord::GetFieldByIdL(unsigned long)
	?GetFieldByIdL@CMDBRecordBase@CommsDat@@UAEPAVCMDBElement@2@K@Z @ 53 NONAME ; class CommsDat::CMDBElement * CommsDat::CMDBRecordBase::GetFieldByIdL(unsigned long)
	?GetFieldByNameL@CMDBGenericRecord@CommsDat@@UAEPAVCMDBElement@2@ABVTPtrC16@@AAH@Z @ 54 NONAME ; class CommsDat::CMDBElement * CommsDat::CMDBGenericRecord::GetFieldByNameL(class TPtrC16 const &, int &)
	?GetFieldByNameL@CMDBRecordBase@CommsDat@@UAEPAVCMDBElement@2@ABVTPtrC16@@AAH@Z @ 55 NONAME ; class CommsDat::CMDBElement * CommsDat::CMDBRecordBase::GetFieldByNameL(class TPtrC16 const &, int &)
	?GetRecordInfo@CMDBRecordBase@CommsDat@@UAEPBUSRecordTypeInfo@2@XZ @ 56 NONAME ; struct CommsDat::SRecordTypeInfo const * CommsDat::CMDBRecordBase::GetRecordInfo(void)
	?GetVDataTable@CCDRecordBase@CommsDat@@MBEPBUSVDataTableEntry@Meta@@XZ @ 57 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CCDRecordBase::GetVDataTable(void) const
	?GetVDataTable@CMDBBinFieldBase@CommsDat@@UBEPBUSVDataTableEntry@Meta@@XZ @ 58 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBBinFieldBase::GetVDataTable(void) const
	?GetVDataTable@CMDBElement@CommsDat@@UBEPBUSVDataTableEntry@Meta@@XZ @ 59 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBElement::GetVDataTable(void) const
	?GetVDataTable@CMDBGenericRecord@CommsDat@@UBEPBUSVDataTableEntry@Meta@@XZ @ 60 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBGenericRecord::GetVDataTable(void) const
	?GetVDataTable@CMDBNumFieldBase@CommsDat@@UBEPBUSVDataTableEntry@Meta@@XZ @ 61 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBNumFieldBase::GetVDataTable(void) const
	?GetVDataTable@CMDBRecordLinkBase@CommsDat@@MBEPBUSVDataTableEntry@Meta@@XZ @ 62 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBRecordLinkBase::GetVDataTable(void) const
	?GetVDataTable@CMDBRecordSetBase@CommsDat@@MBEPBUSVDataTableEntry@Meta@@XZ @ 63 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBRecordSetBase::GetVDataTable(void) const
	?GetVDataTable@CMDBTextFieldBase@CommsDat@@UBEPBUSVDataTableEntry@Meta@@XZ @ 64 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBTextFieldBase::GetVDataTable(void) const
	?IsInTransaction@CMDBSession@CommsDat@@QAEHXZ @ 65 NONAME ; int CommsDat::CMDBSession::IsInTransaction(void)
	?IsNull@CMDBElement@CommsDat@@QBEHXZ @ 66 NONAME ; int CommsDat::CMDBElement::IsNull(void) const
	?IsSetAttribute@CMDBElement@CommsDat@@QBEHK@Z @ 67 NONAME ; int CommsDat::CMDBElement::IsSetAttribute(unsigned long) const
	?LatestVersion@CMDBSession@CommsDat@@SA?AVTVersion@@XZ @ 68 NONAME ; class TVersion CommsDat::CMDBSession::LatestVersion(void)
	?LoadL@MMetaDatabase@CommsDat@@QAEXAAVCMDBSession@2@@Z @ 69 NONAME ; void CommsDat::MMetaDatabase::LoadL(class CommsDat::CMDBSession &)
	?ModifyL@MMetaDatabase@CommsDat@@QAEXAAVCMDBSession@2@@Z @ 70 NONAME ; void CommsDat::MMetaDatabase::ModifyL(class CommsDat::CMDBSession &)
	?NewL@CCommsDatUtils@CommsDatUtils@@SAPAV12@XZ @ 71 NONAME ; class CommsDatUtils::CCommsDatUtils * CommsDatUtils::CCommsDatUtils::NewL(void)
	?NewL@CMDBSession@CommsDat@@SAPAV12@VTVersion@@@Z @ 72 NONAME ; class CommsDat::CMDBSession * CommsDat::CMDBSession::NewL(class TVersion)
	?InitializeL@CMDBGenericRecord@CommsDat@@QAEXABVTDesC16@@PBUSGenericRecordTypeInfoTag@2@@Z @ 73 NONAME ; void CommsDat::CMDBGenericRecord::InitializeL(class TDesC16 const &, struct CommsDat::SGenericRecordTypeInfoTag const *)
	?NewLC@CMDBSession@CommsDat@@SAPAV12@VTVersion@@@Z @ 74 NONAME ; class CommsDat::CMDBSession * CommsDat::CMDBSession::NewLC(class TVersion)
	?OpenTransactionL@CMDBSession@CommsDat@@QAEXXZ @ 75 NONAME ; void CommsDat::CMDBSession::OpenTransactionL(void)
	?PublishProperties@CMDBSession@CommsDat@@QAEHXZ @ 76 NONAME ; int CommsDat::CMDBSession::PublishProperties(void)
	?RecordFactoryL@CCDRecordBase@CommsDat@@SAPAVCMDBRecordBase@2@K@Z @ 77 NONAME ; class CommsDat::CMDBRecordBase * CommsDat::CCDRecordBase::RecordFactoryL(unsigned long)
	?RecordId@CMDBElement@CommsDat@@QBEHXZ @ 78 NONAME ; int CommsDat::CMDBElement::RecordId(void) const
	?RefreshL@MMetaDatabase@CommsDat@@QAEXAAVCMDBSession@2@@Z @ 79 NONAME ; void CommsDat::MMetaDatabase::RefreshL(class CommsDat::CMDBSession &)
	?RequestNotification@MMetaDatabase@CommsDat@@QAEHAAVCMDBSession@2@AAVTRequestStatus@@@Z @ 80 NONAME ; int CommsDat::MMetaDatabase::RequestNotification(class CommsDat::CMDBSession &, class TRequestStatus &)
	?ResolvePhoneNumberFromDatabaseL@CCommsDatUtils@CommsDatUtils@@SAXAAVTDesC16@@AAVTDes16@@W4TParseMode@@KK@Z @ 81 NONAME ; void CommsDatUtils::CCommsDatUtils::ResolvePhoneNumberFromDatabaseL(class TDesC16 &, class TDes16 &, enum TParseMode, unsigned long, unsigned long)
	?ResolvePhoneNumberL@CCommsDatUtils@CommsDatUtils@@SAXAAVTDesC16@@AAVTDes16@@W4TParseMode@@KK@Z @ 82 NONAME ; void CommsDatUtils::CCommsDatUtils::ResolvePhoneNumberL(class TDesC16 &, class TDes16 &, enum TParseMode, unsigned long, unsigned long)
	?RollbackTransactionL@CMDBSession@CommsDat@@QAEXXZ @ 83 NONAME ; void CommsDat::CMDBSession::RollbackTransactionL(void)
	?SetAttributeMask@CMDBSession@CommsDat@@QAEXK@Z @ 84 NONAME ; void CommsDat::CMDBSession::SetAttributeMask(unsigned long)
	?SetAttributes@CMDBElement@CommsDat@@QAEXK@Z @ 85 NONAME ; void CommsDat::CMDBElement::SetAttributes(unsigned long)
	?SetElementId@CMDBElement@CommsDat@@QAEXK@Z @ 86 NONAME ; void CommsDat::CMDBElement::SetElementId(unsigned long)
	?SetMaxLengthL@CMDBBinFieldBase@CommsDat@@QAEXH@Z @ 87 NONAME ; void CommsDat::CMDBBinFieldBase::SetMaxLengthL(int)
	?SetMaxLengthL@CMDBNumFieldBase@CommsDat@@QAEXH@Z @ 88 NONAME ; void CommsDat::CMDBNumFieldBase::SetMaxLengthL(int)
	?SetMaxLengthL@CMDBTextFieldBase@CommsDat@@QAEXH@Z @ 89 NONAME ; void CommsDat::CMDBTextFieldBase::SetMaxLengthL(int)
	?SetRecordId@CMDBElement@CommsDat@@QAEXH@Z @ 90 NONAME ; void CommsDat::CMDBElement::SetRecordId(int)
	?SetTypeId@CMDBElement@CommsDat@@QAEXK@Z @ 91 NONAME ; void CommsDat::CMDBElement::SetTypeId(unsigned long)
	?StoreL@MMetaDatabase@CommsDat@@QAEXAAVCMDBSession@2@@Z @ 92 NONAME ; void CommsDat::MMetaDatabase::StoreL(class CommsDat::CMDBSession &)
	?TMDBBinVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 93 NONAME ; class Meta::MMetaType * Meta::TMDBBinVisitorFactoryL(void const *, void const *)
	?TMDBGenericRecordVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 94 NONAME ; class Meta::MMetaType * Meta::TMDBGenericRecordVisitorFactoryL(void const *, void const *)
	?TMDBLinkVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 95 NONAME ; class Meta::MMetaType * Meta::TMDBLinkVisitorFactoryL(void const *, void const *)
	?TMDBLongTextVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 96 NONAME ; class Meta::MMetaType * Meta::TMDBLongTextVisitorFactoryL(void const *, void const *)
	?TMDBMedTextVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 97 NONAME ; class Meta::MMetaType * Meta::TMDBMedTextVisitorFactoryL(void const *, void const *)
	?TMDBNumVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 98 NONAME ; class Meta::MMetaType * Meta::TMDBNumVisitorFactoryL(void const *, void const *)
	?TMDBRecordSetVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 99 NONAME ; class Meta::MMetaType * Meta::TMDBRecordSetVisitorFactoryL(void const *, void const *)
	?TMDBTextVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 100 NONAME ; class Meta::MMetaType * Meta::TMDBTextVisitorFactoryL(void const *, void const *)
	?TypeId@CMDBElement@CommsDat@@QBEKXZ @ 101 NONAME ; unsigned long CommsDat::CMDBElement::TypeId(void) const
	?VersionInUse@CMDBSession@CommsDat@@QAE?AVTVersion@@XZ @ 102 NONAME ; class TVersion CommsDat::CMDBSession::VersionInUse(void)
	?GetVDataTableStatic@CCDRecordBase@CommsDat@@KAPBUSVDataTableEntry@Meta@@XZ @ 103 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CCDRecordBase::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBBinFieldBase@CommsDat@@SAPBUSVDataTableEntry@Meta@@XZ @ 104 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBBinFieldBase::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBElement@CommsDat@@SAPBUSVDataTableEntry@Meta@@XZ @ 105 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBElement::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBGenericRecord@CommsDat@@SAPBUSVDataTableEntry@Meta@@XZ @ 106 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBGenericRecord::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBNumFieldBase@CommsDat@@SAPBUSVDataTableEntry@Meta@@XZ @ 107 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBNumFieldBase::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBRecordLinkBase@CommsDat@@KAPBUSVDataTableEntry@Meta@@XZ @ 108 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBRecordLinkBase::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBRecordSetBase@CommsDat@@KAPBUSVDataTableEntry@Meta@@XZ @ 109 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBRecordSetBase::GetVDataTableStatic(void)
	?GetVDataTableStatic@CMDBTextFieldBase@CommsDat@@SAPBUSVDataTableEntry@Meta@@XZ @ 110 NONAME ; struct Meta::SVDataTableEntry const * CommsDat::CMDBTextFieldBase::GetVDataTableStatic(void)
	?ClearAttributeMask@CMDBSession@CommsDat@@QAEXK@Z @ 111 NONAME ; void CommsDat::CMDBSession::ClearAttributeMask(unsigned long)
	?IsSetAttributeMask@CMDBSession@CommsDat@@QAEHK@Z @ 112 NONAME ; int CommsDat::CMDBSession::IsSetAttributeMask(unsigned long)
	?TableId@CMDBElement@CommsDat@@QBEKXZ @ 113 NONAME ; unsigned long CommsDat::CMDBElement::TableId(void) const
	?FieldNameLookup@NameLookUp@CommsDatUtils@@SAHKAAPAVHBufC16@@AAH@Z @ 114 NONAME ; int CommsDatUtils::NameLookUp::FieldNameLookup(unsigned long, class HBufC16 * &, int &)
	?TMDBLinkNumVisitorFactoryL@Meta@@YAPAVMMetaType@1@PBX0@Z @ 115 NONAME ; class Meta::MMetaType * Meta::TMDBLinkNumVisitorFactoryL(void const *, void const *)

